@@ -33,12 +33,19 @@ You should have received a copy of the 3-Clause BSD License along with this
 program. If not, see <https://opensource.org/licenses/BSD-3-Clause>
 """
 
-__version__ = "1.0.0"
+__version__ = "1.1.1"
 
 from .detectors import (
   AGIPD_1MGeometry, AGIPD_500K2GGeometry, DSSC_1MGeometry, JUNGFRAUGeometry,
-  LPD_1MGeometry, PNCCDGeometry
+  LPD_1MGeometry, PNCCDGeometry, agipd_asic_seams,
 )
 
-__all__ = ['AGIPD_1MGeometry', 'AGIPD_500K2GGeometry', 'DSSC_1MGeometry',
-           'JUNGFRAUGeometry', 'LPD_1MGeometry', 'PNCCDGeometry']
+__all__ = [
+    'AGIPD_1MGeometry',
+    'AGIPD_500K2GGeometry',
+    'agipd_asic_seams',
+    'DSSC_1MGeometry',
+    'JUNGFRAUGeometry',
+    'LPD_1MGeometry',
+    'PNCCDGeometry',
+]
