@@ -55,6 +55,10 @@ class GeometryFragment:
             + (0.5 * self.fs_vec * self.fs_pixels)
         )
 
+    def offset(self, shift):
+        pos = self.corner_pos + shift
+        return type(self)(pos, self.ss_vec, self.fs_vec, self.ss_pixels, self.fs_pixels)
+
     def snap(self, px_shape):
         # Round positions and vectors to integers, drop z dimension
         corner_pos = np.around(self.corner_pos[:2] / px_shape).astype(np.int32)
@@ -369,12 +373,44 @@ class DetectorGeometryBase:
         centre : ndarray
           (y, x) pixel location of the detector centre in this geometry.
         """
-        return self._snapped().position_modules(data, out=out)
+        return self._snapped().position_modules(data, out=out, threadpool=threadpool)
 
     def position_all_modules(self, data, out=None):
         """Deprecated alias for :meth:`position_modules_fast`"""
         return self.position_modules_fast(data, out=out)
 
+    def position_modules_symmetric(self, data, out=None, threadpool=None):
+        """Assemble data with the centre in the middle of the output array.
+
+        The assembly process is the same as :meth:`position_modules_fast`,
+        aligning each module to a single pixel grid. But this makes the output
+        array symmetric, with the centre at (height // 2, width // 2).
+
+        Parameters
+        ----------
+
+        data : ndarray
+          The last three dimensions should match the modules, then the
+          slow scan and fast scan pixel dimensions.
+        out : ndarray, optional
+          An output array to assemble the image into. By default, a new
+          array is created at the minimum size to allow symmetric assembly.
+          If an array is passed in, its last two dimensions must be at least
+          this size.
+        threadpool : concurrent.futures.ThreadPoolExecutor, optional
+          If passed, parallelise copying data into the output image.
+          See :meth:`position_modules_fast` for details.
+
+        Returns
+        -------
+        out : ndarray
+          Array with one dimension fewer than the input.
+          The last two dimensions represent pixel y and x in the detector space.
+        """
+        return self._snapped().position_modules_symmetric(
+            data, out=out, threadpool=threadpool
+        )
+
     def plot_data_fast(self,
                        data, *,
                        axis_units='px',
@@ -623,6 +659,77 @@ class DetectorGeometryBase:
             + (np.expand_dims(tile_ss, -1) * coords_ss_vec) \
             + (np.expand_dims(tile_fs, -1) * coords_fs_vec)
 
+    def offset(self, shift, *, modules=np.s_[:], tiles=np.s_[:]):
+        """Move part or all of the detector, making a new geometry.
+
+        By default, this moves all modules & tiles. To move the centre down in
+        the image, move the whole geometry *up* relative to it.
+
+        Returns a new geometry object of the same type.
+
+        ::
+
+            # Move the whole geometry up 2 mm (relative to the beam)
+            geom2 = geom.shift((0, 2e-3))
+
+            # Move quadrant 1 (modules 0, 1, 2, 3) up 2 mm
+            geom2 = geom.shift((0, 2e-3), modules=np.s_[0:4])
+
+            # Move each module by a separate amount
+            shifts = np.zeros((16, 3))
+            shifts[5] = (0, 2e-3, 0)    # x, y, z for individual modules
+            shifts[10] = (0, -1e-3, 0)
+            geom2 = geom.shift(shifts)
+
+        Parameters
+        ----------
+
+        shift: numpy.ndarray or tuple
+          (x, y) or (x, y, z) shift to apply in metres. Can be a single shift
+          for all selected modules, a 2D array with a shift per module, or a
+          3D array with a shift per tile (``arr[module, tile, xyz]``).
+        modules: slice
+          Select modules to move; defaults to all modules.
+          Like all Python slicing, the end number is excluded, so ``np.s_[:4]``
+          moves modules 0, 1, 2, 3.
+        tiles: slice
+          Select tiles to move within each module; defaults to all tiles.
+        """
+        shift = np.asarray(shift)
+        if not shift.shape[-1] in (2, 3):
+            raise ValueError(
+                "Shift must be 2D or 3D coordinate(s). Last dimension "
+                f"was {shift.shape[-1]}"
+            )
+
+        ntiles = max([len(m) for m in self.modules])
+        all_shifts = np.zeros((len(self.modules), ntiles, 3), dtype=shift.dtype)
+        sel_shifts = all_shifts[modules, tiles, :shift.shape[-1]]
+
+        if shift.shape[:-1] == sel_shifts.shape[:2]:
+            # Per-tile offsets
+            sel_shifts[:] = shift
+        elif shift.shape[:-1] == sel_shifts.shape[:1]:
+            # Per-module offsets - broadcast across tiles
+            sel_shifts[:] = shift[:, np.newaxis]
+        elif shift.shape[:-1] == ():
+            # Single shift - broadcast across modules and tiles
+            sel_shifts[:] = shift
+        else:
+            raise ValueError(
+                f"Got {shift.shape[:-1]} coordinates. Expected either a single "
+                f"coordinate (), a coordinate per module {sel_shifts.shape[:1]} "
+                f"or a coordinate per tile {sel_shifts.shape[:2]}"
+            )
+
+        cls = type(self)
+        return cls([
+            [
+                tile.offset(all_shifts[m, t])
+                for t, tile in enumerate(module)
+            ] for m, module in enumerate(self.modules)
+        ])
+
 
 class AGIPD_1MGeometry(DetectorGeometryBase):
     """Detector layout for AGIPD-1M
@@ -909,12 +1016,16 @@ class AGIPD_500K2GGeometry(DetectorGeometryBase):
         module_height = cls.frag_fs_pixels * cls.pixel_size
         # In x, 64 px + gap between tiles (asics)
         tile_width = (cls.frag_ss_pixels + asic_gap_px) * cls.pixel_size
-        module_width = 8 * tile_width
+        module_width = 8 * tile_width - asic_gap_px * cls.pixel_size  # 8 tiles + 7 gaps
 
         # coordinates relative to the first pixel of the first module
         # detector's bottom-right corner
-        ref = (0, - (3 * (cls.frag_fs_pixels + panel_gap[1]) * unit))  
-        ref = (- (origin[0] * unit + ref[0]), - (origin[1] * unit + ref[1]))  # origin
+        ref = (
+            - module_width,  # x
+            - (3 * (cls.frag_fs_pixels + panel_gap[1]) * unit)  # y
+        )
+        # origin
+        ref = (- (origin[0] * unit + ref[0]), - (origin[1] * unit + ref[1]))
 
         modules = []
         for p in range(cls.n_modules):
@@ -925,11 +1036,11 @@ class AGIPD_500K2GGeometry(DetectorGeometryBase):
             modules.append(tiles)
 
             for a in range(cls.n_tiles_per_module):
-                corner_x = panel_corner_x + a * tile_width
+                corner_x = panel_corner_x - a * tile_width
 
                 tiles.append(GeometryFragment(
                     corner_pos=np.array([corner_x, panel_corner_y, 0.]),
-                    ss_vec=np.array([1, 0, 0]) * unit,
+                    ss_vec=np.array([-1, 0, 0]) * unit,
                     fs_vec=np.array([0, 1, 0]) * unit,
                     ss_pixels=cls.frag_ss_pixels,
                     fs_pixels=cls.frag_fs_pixels,
@@ -1020,6 +1131,19 @@ class AGIPD_500K2GGeometry(DetectorGeometryBase):
         super().write_crystfel_geom(*args, nquads=1, **kwargs)
 
 
+def agipd_asic_seams():
+    """Make a boolean array marking the double-width pixels in an AGIPD module
+
+    This returns a (512, 128) array with False for normal (square) pixels, and
+    True for the 400 x 200 µm pixels at the horizontal joins between ASICs.
+    """
+    arr = np.zeros((512, 128), dtype=np.bool)
+    # The outer edges (indexes 0 & 511) appear to be normal pixels
+    arr[64::64] = True
+    arr[63:511:64] = True
+    return arr
+
+
 class LPD_1MGeometry(DetectorGeometryBase):
     """Detector layout for LPD-1M
 
